<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Invax
 */
	$invax_blog_title = invax_theme_option( 'blog-title' );
	$invax_blog_sub_title = invax_theme_option( 'blog-sub-title' );
	$invax_blog_sidebar = invax_theme_option( 'blog-sidebar' );

	if( ! isset( $invax_blog_title ) ){
		$invax_blog_title = esc_html__( 'Blog ', 'invax' );
		$invax_blog_sub_title = esc_html__( 'Blog', 'invax' );
		$invax_blog_sidebar = "right-sidebar";
	}

	$invax_blog_class = "col-md-12";
	if( !isset( $invax_blog_sidebar )  && ! is_active_sidebar( 'sidebar-1' )  ){
		$invax_blog_class = "col-md-12";
	}

	if( $invax_blog_sidebar == "right-sidebar" ){
		$invax_blog_class = "col-md-8 blog-page-right";
	}elseif( $invax_blog_sidebar == "left-sidebar" ){
			$invax_blog_class = "col-md-7 col-md-offset-1";
	}

	get_header(); 
	?>

	<div class="finance-breadcrumb-area blog-breadcrumb-bg">
		<div class="container">
			<div class="row">
				<div class="col-md-12">
					<?php if( !empty( $invax_blog_title ) ): ?>
						<h1><?php echo esc_html( $invax_blog_title ); ?></h1>
					<?php endif; ?>
					<a href="<?php echo esc_url( home_url('/') ); ?>"><?php esc_html_e('Home', 'invax'); ?></a>
						&nbsp; / &nbsp; 
					<span class="current"><?php echo esc_html( $invax_blog_sub_title ); ?></span>
				</div>
			</div>
		</div>
	</div>

	<div class="finance-internal-area finance-v-composer-disabled">
		<div class="container">
			<div class="row">
				<?php  
					if( $invax_blog_sidebar == 'left-sidebar' ):
						get_sidebar(); 
					endif;
				?>
				<div class="<?php echo esc_html( $invax_blog_class ); ?> ">
					<?php
						if ( have_posts() ) :

							if ( is_home() && ! is_front_page() ) : ?>
								<header>
									<h1 class="page-title screen-reader-text"><?php single_post_title(); ?></h1>
								</header>

							<?php
							endif;

							/* Start the Loop */
							while ( have_posts() ) : the_post();

								/*
								 * Include the Post-Format-specific template for the content.
								 * If you want to override this in a child theme, then include a file
								 * called content-___.php (where ___ is the Post Format name) and that will be used instead.
								 */
								get_template_part( 'template-parts/content', get_post_format() );

							endwhile;

							the_posts_navigation();

						else :

							get_template_part( 'template-parts/content', 'none' );

						endif; ?>
				</div>
				<?php  
					if( $invax_blog_sidebar == 'right-sidebar' ):
						get_sidebar(); 
					endif;
				?>
			</div>
		</div>
	</div>

<?php
get_footer();
